==> worker_2.17.8.orig.tar.bz2: worker-2.17.8/src/scrolllisterop.h <==
/* scrolllisterop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/* $Id: scrolllisterop.h,v 1.9 2005/10/19 18:02:09 ralf Exp $ */

#ifndef SCROLLLISTEROP_H
#define SCROLLLISTEROP_H

#include "wdefines.h"
#include "functionproto.h"
#include <aguix/awindow.h>
#include <aguix/text.h>
#include <aguix/solidbutton.h>
#include <aguix/button.h>
#include <aguix/cyclebutton.h>

class ScrollListerOp:public FunctionProto
{
public:
  ScrollListerOp();
  virtual ~ScrollListerOp();
  ScrollListerOp( const ScrollListerOp &other );
  ScrollListerOp &operator=( const ScrollListerOp &other );

  virtual ScrollListerOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  int run( WPUContext *wpu, ActionMessage* );
  virtual bool save(Datei*);
  virtual const char *getDescription();
  virtual int configure();

  typedef enum {SCROLLLISTEROP_LEFT=0,
                SCROLLLISTEROP_RIGHT} scrolllister_t;
  void setDir(scrolllister_t);
protected:
  static const char *name;
  // Infos to save
  scrolllister_t dir;

  // temp variables
  Lister *startlister;
  
  void normalmodescrolllister( ActionMessage *am );
};

#endif

==> worker_4.4.0.orig.tar.bz2: worker-4.4.0/src/scrolllisterop.h <==
/* scrolllisterop.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2004,2011 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef SCROLLLISTEROP_H
#define SCROLLLISTEROP_H

#include "wdefines.h"
#include "functionproto.h"

class ScrollListerOp:public FunctionProto
{
public:
  ScrollListerOp();
  virtual ~ScrollListerOp();
  ScrollListerOp( const ScrollListerOp &other );
  ScrollListerOp &operator=( const ScrollListerOp &other );

  virtual ScrollListerOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  int run( WPUContext *wpu, ActionMessage* );
  virtual bool save(Datei*);
  virtual const char *getDescription();
  virtual int configure();

  typedef enum {SCROLLLISTEROP_LEFT=0,
                SCROLLLISTEROP_RIGHT} scrolllister_t;
  void setDir(scrolllister_t);
protected:
  static const char *name;
  // Infos to save
  scrolllister_t dir;

  // temp variables
  Lister *startlister;
  
  void normalmodescrolllister( ActionMessage *am );
};

#endif

/* Local Variables: */
/* mode:c++ */
/* End: */
